Jemalloc

Struct Jemalloc 

pub struct Jemalloc;
Handle to the jemalloc allocator

This type implements the GlobalAllocAlloc trait, allowing usage a global allocator.

When the api feature of this crate is enabled, it also implements the Allocator trait, allowing usage in collections.